static int SLang_pop_scomplex (spcomplex *c)
{
   double dc[2];
   if (SLang_pop_complex(dc, dc+1) == -1)
	return -1;
   c->r = (float) dc[0]; /* information may be lost to truncation */
   c->i = (float) dc[1];
   return 0;
}

#define SLang_pop_dcomplex(dc)	SLang_pop_complex((double*)dc,((double*)dc)+1)
